@@ -12,7 +12,7 @@ import math
 import urllib
 import netCDF4 as nc
 
-from coordinate_systems import CS
+from cht.coordinate_systems import CS
 
 class ZoomLevel:
 
