@@ -39,7 +39,9 @@ def make_png_tiles(valg, index_path, png_path,
                    merge=True,
                    depth=None):
     
-    if valg.any():
+    if type(valg) == list:
+        pass
+    else:
         valg = valg.transpose().flatten()
 
     if not caxis:
@@ -180,13 +182,13 @@ def make_png_tiles(valg, index_path, png_path,
 def make_topobathy_tiles(path, dem_names, lon_range, lat_range,
                          index_path=None,
                          zoom_range=None,
-                         z_range=None):
+                         z_range=None,
+                         bathymetry_database_path="d:\\delftdashboard\\data\\bathymetry"):
     
     from cht.bathymetry_database import BathymetryDatabase
     from cht.misc_tools import interp2
     
-    pth = "d:\\delftdashboard\\data\\bathymetry"
-    bathymetry_database = BathymetryDatabase(pth)
+    bathymetry_database = BathymetryDatabase(bathymetry_database_path)
 
     if not zoom_range:
         zoom_range = [0, 13]
@@ -285,7 +287,7 @@ def make_topobathy_tiles(path, dem_names, lon_range, lat_range,
                         break
                     
                 if np.isnan(zg).all():
-                    # only neans in this tile
+                    # only nans in this tile
                     break
                     
                 if np.nanmax(zg)<z_range[0] or np.nanmin(zg)>z_range[1]:
